<?php
/**
 * Plugin Name: Ask Me
 * Plugin URI: http://de.kilo-moana.com/
 * Description: Simple Plugin to let your users ask questions.
 * Version: 0.2
 * Author: Timo Schiller, Alexander Siemer-Schmetzke
 * Author URI: http://de.kilo-moana.com/
 * Text Domain: askme-plugin
 * License: CC0
 */

function askme_init() {
    $plugin_dir = basename(dirname(__FILE__));
    load_plugin_textdomain( 'askme-plugin', false, $plugin_dir );
}
add_action('plugins_loaded', 'askme_init');

function create_askme_postype() {

    $labels = array(
        'name' => _x('Ask Me', 'The Questions', 'askme-plugin'),
        'singular_name' => _x('Ask Me', 'Question', 'askme-plugin'),
        'add_new' => _x('New Ask Me', 'New Question', 'askme-plugin'),
        'add_new_item' => __('Add new Ask Me', 'askme-plugin'),
        'edit_item' => __('Edit Ask Me', 'askme-plugin'),
        'new_item' => __('New Ask Me', 'askme-plugin'),
        'view_item' => __('View Ask Me', 'askme-plugin'),
        'search_items' => __('Search Ask Me s', 'askme-plugin'),
        'not_found' =>  __('No Ask Me found', 'askme-plugin'),
        'not_found_in_trash' => __('No Ask Me found in Trash', 'askme-plugin'),
        'parent_item_colon' => '',
    );

    $args = array(
        'label' => __('Ask me', 'askme-plugin'),
        'labels' => $labels,
        'public' => false,
        'can_export' => true,
        'show_ui' => true,
        'menu_position'     => 32,
        '_builtin' => false,
        'capability_type' => 'post',
        'menu_icon'         => plugin_dir_url(__FILE__).'images/icon.png',
        'hierarchical' => false,
        'rewrite' => array( "slug" => "askme" ),
        'supports'=> array('title', 'editor', 'comments'),
        'show_in_nav_menus' => true
    );

    register_post_type( 'askme', $args);
}

add_action( 'init', 'create_askme_postype' );

function askme_title_placeholder( $title ){

    $screen = get_current_screen();

    if ( 'askme' == $screen->post_type ){
        $title = __('your question here', 'askme-plugin');
    }

    return $title;
}

add_filter( 'enter_title_here', 'askme_title_placeholder' );

function show_asks(  ) {
    ob_start();
    wp_enqueue_style( 'askme', plugins_url('askme.css',__FILE__) );

    if( 'POST' == $_SERVER['REQUEST_METHOD']
        && !empty( $_POST['action'] )
        && $_POST['post_type'] == 'askme' ) {

        $title =  $_POST['question'];

        $post = array(
            'post_title'	=> $title,
            'post_status'	=> 'draft',
            'post_type'		=> 'askme'
        );

        wp_insert_post($post);
        if(get_option('askme_setting_email') == true)
        {
            $admin_email = get_option('admin_email');
            wp_mail( $admin_email,  __('New Ask Me Received', 'askme-plugin'), "Ask Me: ".$title);
        }
    }
    ?>

    <div id="askme">
        <form id="newask" name="newask" method="post" action="">

            <p><label for="question"><?php _e('Question to ask', 'askme-plugin'); ?></label><br />
            <input type="text" id="question" value="" tabindex="1" size="20" name="question" /></p>

            <p><input type="submit" value="Ask Me" tabindex="6" id="submit" name="submit" /></p>
            <input type="hidden" name="post_type" id="post_type" value="askme" />
            <input type="hidden" name="action" value="post" />
            <?php wp_nonce_field( 'new-post' ); ?>

        </form>
    <?php
    // TODO: Switch Ajax / Normal
    askme_output_normal();

    $output = ob_get_contents();
    ob_end_clean();
    return $output;
}
add_shortcode('askme', 'show_asks');

function askme_output_normal()
{
        global $wp_query;

        if ( get_query_var('paged') ) {
            $paged = get_query_var('paged');
        } else if ( get_query_var('page') ) {
            $paged = get_query_var('page');
        } else {
            $paged = 1;
        }

        $args = array(
            'post_type' => 'askme',
            'post_status' => 'publish',
            'paged' => $paged,
            'orderby' => 'date',
            'posts_per_page' => 5
        );

        query_posts($args);

        while ( have_posts() ) : the_post(); ?>

            <div class="entry">
                <div class="question">
                    <strong><?php the_title(); ?></strong>
                    <span class="date"><?php the_time('j. F Y'); ?></span>
                </div>

                <div class="answer">
                    <p><?php the_content(); ?></p>
                </div>
            </div>

            <hr />

        <?php endwhile; ?>
        <?php askme_pagination($wp_query->max_num_pages); ?>
    </div> <!-- Ende Askme Div -->
    <?php
    wp_reset_query();
}

function askme_pagination($pages = '', $range = 5)
{
    $showitems = ($range * 2)+1;

    global $paged;

    if ( get_query_var('paged') ) {
        $paged = get_query_var('paged');
    } else if ( get_query_var('page') ) {
        $paged = get_query_var('page');
    } else {
        $paged = 1;
    }

    if($pages == '')
    {
        global $wp_query;
        $pages = $wp_query->max_num_pages;

        if(!$pages)
        {
            $pages = 1;
        }
    }

    if(1 != $pages)
    {
        ?>
        <div class="askme_pagination"><span><?php echo __('Page', 'askme-plugin'); ?> <?php echo $paged; ?> <?php echo __('of', 'askme-plugin');?> <?php echo $pages; ?></span>
            <?php
            if($paged > 2 && $paged > $range+1 && $showitems < $pages)
            { ?>

                <a href="<?php echo get_pagenum_link(1); ?>">&laquo;</a>

            <?php }

            if($paged > 1)
            { ?>
                <a href="<?php echo get_pagenum_link($paged - 1); ?>">&lsaquo;</a>;
            <?php }

            for ($i=1; $i <= $pages; $i++)
            {
                if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
                {
                    if ($paged == $i)
                    { ?>
                        <span class="current"><?php echo $i; ?></span>
                    <?php }
                    else
                    { ?>
                        <a href="<?php echo get_pagenum_link($i); ?>" class="inactive"><?php echo $i; ?></a>
                    <?php }
                }
            }

            if ($paged < $pages)
            { ?>
                <a href="<?php echo get_pagenum_link($paged + 1); ?>">&rsaquo;</a>
            <?php }
            if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages)
            { ?>
                <a href="<?php echo get_pagenum_link($pages); ?>">&raquo;</a>
            <?php }
            ?>
        </div>
        <?php
    }
}

function askme_stats() {
?>
    <h4>Ask Me - Overview</h4>
    <br />
    <ul>
	    <li class="post-count">
            <?php
            $type = 'askme';
            $args = array(
                'post_type' => $type,
                'post_status' => 'publish',
                'posts_per_page' => -1);

            $my_query = query_posts( $args );
            ?>

            <a href="edit.php?post_type=askme&post_status=publish"><?php echo count($my_query); ?> <?php _e('published', 'askme-plugin'); ?></a>
        </li>
        <li class="page-count">
            <?php
            $args = array(
                'post_type' => $type,
                'post_status' => 'draft',
                'posts_per_page' => -1);

            $my_query = query_posts( $args );
            ?>
            <a href="edit.php?post_type=askme&post_status=draft"><?php echo count($my_query); ?> <?php _e('open', 'askme-plugin'); ?></a>

        </li>
    </ul>
<?php
    wp_reset_query();
}

add_action('activity_box_end', 'askme_stats');

function askme_settings_init() {

    add_settings_section(
        'askme_setting_section',
        __('Ask Me Settings', 'askme-plugin'),
        'askme_setting_section_callback',
        'reading'
    );

 	add_settings_field(
        'askme_setting_email',
        __('E-Mail Alert on new Ask', 'askme-plugin'),
        'askme_setting_callback',
        'reading',
        'askme_setting_section'
    );

 	register_setting( 'reading', 'askme_setting_email' );

 }

 add_action( 'admin_init', 'askme_settings_init' );

function askme_setting_section_callback() {
     echo '<p>'.__("Configure your Asks", "askme-plugin").'</p>';
}

function askme_setting_callback() {
    echo '<input name="askme_setting_email" id="gv_thumbnails_insert_into_excerpt" type="checkbox" value="1" class="code" ' . checked( 1, get_option( 'askme_setting_email' ), false ) . ' />';
}

add_action( 'admin_menu', 'add_user_menu_bubble' );

function add_user_menu_bubble() {

    global $menu;

    foreach ( $menu as $key => $value ) {
        if ( $menu[$key][2] == 'edit.php?post_type=askme' ) {

            $type = 'askme';
            $args = array(
                'post_type' => $type,
                'post_status' => 'draft',
                'posts_per_page' => -1);

            $my_query = query_posts( $args );
            if(count($my_query) > 0)
            {
                $menu[$key][0] .= '    <span class="update-plugins"><span class="plugin-count">' . count($my_query) . '</span></span> ';
            }
            wp_reset_query();
            return;
        }
    }

}


?>